@@ -1,5 +1,5 @@
 package Module::Format::Module;
-$Module::Format::Module::VERSION = '0.2.0';
+$Module::Format::Module::VERSION = '0.4.0';
 use warnings;
 use strict;
 
@@ -7,7 +7,7 @@ use strict;
 sub _new
 {
     my $class = shift;
-    my $self = bless {}, $class;
+    my $self  = bless {}, $class;
     $self->_init(@_);
     return $self;
 }
@@ -184,6 +184,12 @@ my @formats_by_priority = (
             return 'lib' . lc( $self->format_as('dash') ) . '-perl';
         },
     },
+    _gen_dash_format(
+        {
+            name   => 'freebsd_dash',
+            prefix => 'p5-',
+        }
+    ),
 );
 
 my %formats = ( map { $_->{name} => $_ } @formats_by_priority );
@@ -292,7 +298,7 @@ sub from_guess
 
     my $dummy_format_string;
 
-    my $string = $args->{value};
+    my $string         = $args->{value};
     my $out_format_ref = ( $args->{format_ref} || ( \$dummy_format_string ) );
 
     # TODO : After the previous line the indentation in vim is reset to the
@@ -332,7 +338,7 @@ Module::Format::Module - encapsulates a single Perl module.
 
 =head1 VERSION
 
-version 0.2.0
+version 0.4.0
 
 =head1 SYNOPSIS
 
@@ -388,10 +394,6 @@ version 0.2.0
     # Prints "libxml-rss-perl"
     print $module->format_as('debian'), "\n";
 
-=head1 VERSION
-
-version 0.2.0
-
 =head1 FUNCTIONS
 
 =head2 my $module = Module::Format::Module->from_components({components => [@components]})
@@ -455,6 +457,10 @@ C<https://metacpan.org/pod/Module::Format> , C<https://metacpan.org/pod/Data::Pa
 Debian package format, such as C<libxml-rss-perl>,
 C<libcatalyst-plugin-authentication-perl> . Output only.
 
+=item * 'freebsd_dash'
+
+Like dash, only with C<'p5-'> prefixed: C<p5-XML-RSS>, C<p5-Data-Dumper>.
+
 =back
 
 =head2 my $array_ref = $module->get_components_list()
@@ -547,37 +553,10 @@ WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 OTHER DEALINGS IN THE SOFTWARE.
 
-=head1 AUTHOR
-
-Shlomi Fish <shlomif@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is Copyright (c) 2018 by Shlomi Fish.
-
-This is free software, licensed under:
-
-  The MIT (X11) License
-
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website
-L<https://github.com/shlomif/perl-Module-Format/issues>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
-=head2 Perldoc
-
-You can find documentation for this module with the perldoc command.
-
-  perldoc Module::Format::Module
-
 =head2 Websites
 
 The following websites have more information about this module, and may be of help to you. As always,
@@ -595,14 +574,6 @@ L<https://metacpan.org/release/Module-Format>
 
 =item *
 
-Search CPAN
-
-The default CPAN search engine, useful to view POD in HTML format.
-
-L<http://search.cpan.org/dist/Module-Format>
-
-=item *
-
 RT: CPAN's Bug Tracker
 
 The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
@@ -611,22 +582,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=Module-Format>
 
 =item *
 
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/Module-Format>
-
-=item *
-
-CPAN Ratings
-
-The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
-
-L<http://cpanratings.perl.org/d/Module-Format>
-
-=item *
-
 CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
@@ -675,4 +630,25 @@ L<https://github.com/shlomif/perl-Module-Format>
 
   git clone git://github.com/shlomif/perl-Module-Format.git
 
+=head1 AUTHOR
+
+Shlomi Fish <shlomif@cpan.org>
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+L<https://github.com/shlomif/perl-Module-Format/issues>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2018 by Shlomi Fish.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
 =cut
