@@ -1,5 +1,5 @@
 package Module::Format::ModuleList;
-$Module::Format::ModuleList::VERSION = '0.2.0';
+$Module::Format::ModuleList::VERSION = '0.4.0';
 use warnings;
 use strict;
 
@@ -10,7 +10,7 @@ use Module::Format::Module;
 sub new
 {
     my $class = shift;
-    my $self = bless {}, $class;
+    my $self  = bless {}, $class;
     $self->_init(@_);
     return $self;
 }
@@ -108,7 +108,7 @@ Module::Format::ModuleList - an ordered list of L<Module::Format::Module>.
 
 =head1 VERSION
 
-version 0.2.0
+version 0.4.0
 
 =head1 SYNOPSIS
 
@@ -140,10 +140,6 @@ version 0.2.0
         },
     )
 
-=head1 VERSION
-
-version 0.2.0
-
 =head1 FUNCTIONS
 
 =head2 my $list = Module::Format::ModuleList->new({ modules => \@list})
@@ -231,37 +227,10 @@ WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 OTHER DEALINGS IN THE SOFTWARE.
 
-=head1 AUTHOR
-
-Shlomi Fish <shlomif@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is Copyright (c) 2018 by Shlomi Fish.
-
-This is free software, licensed under:
-
-  The MIT (X11) License
-
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website
-L<https://github.com/shlomif/perl-Module-Format/issues>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
-=head2 Perldoc
-
-You can find documentation for this module with the perldoc command.
-
-  perldoc Module::Format::ModuleList
-
 =head2 Websites
 
 The following websites have more information about this module, and may be of help to you. As always,
@@ -279,14 +248,6 @@ L<https://metacpan.org/release/Module-Format>
 
 =item *
 
-Search CPAN
-
-The default CPAN search engine, useful to view POD in HTML format.
-
-L<http://search.cpan.org/dist/Module-Format>
-
-=item *
-
 RT: CPAN's Bug Tracker
 
 The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
@@ -295,22 +256,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=Module-Format>
 
 =item *
 
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/Module-Format>
-
-=item *
-
-CPAN Ratings
-
-The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
-
-L<http://cpanratings.perl.org/d/Module-Format>
-
-=item *
-
 CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
@@ -359,4 +304,25 @@ L<https://github.com/shlomif/perl-Module-Format>
 
   git clone git://github.com/shlomif/perl-Module-Format.git
 
+=head1 AUTHOR
+
+Shlomi Fish <shlomif@cpan.org>
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+L<https://github.com/shlomif/perl-Module-Format/issues>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2018 by Shlomi Fish.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
 =cut
